import React, { useContext } from 'react';
import { useHistory, useRouteMatch } from 'react-router-dom';
import ConfigContext from 'base-shell/lib/providers/Config/Context';
import MenuContext from 'material-ui-shell/lib/providers/Menu/Context';
import { useIntl } from 'react-intl';
import ResponsiveMenu from '../ResponsiveMenu/ResponsiveMenu';
import SelectableMenuList from 'material-ui-shell/lib/containers/SelectableMenuList';
import LocaleContext from 'base-shell/lib/providers/Locale/Context';
import A2HSContext from 'base-shell/lib/providers/AddToHomeScreen/Context';
import Scrollbar from 'material-ui-shell/lib/components/Scrollbar/Scrollbar';
import ThemeContext from 'material-ui-shell/lib/providers/Theme/Context';

var Menu = function Menu() {
  var intl = useIntl();
  var history = useHistory();
  var match = useRouteMatch();
  var menuContext = useContext(MenuContext);
  var a2HSContext = useContext(A2HSContext);
  var isDesktopOpen = menuContext.isDesktopOpen,
      isMini = menuContext.isMini,
      setDesktopOpen = menuContext.setDesktopOpen,
      setMobileOpen = menuContext.setMobileOpen,
      useMiniMode = menuContext.useMiniMode;

  var _useContext = useContext(ConfigContext),
      appConfig = _useContext.appConfig;

  var _useContext2 = useContext(LocaleContext),
      setLocale = _useContext2.setLocale,
      _useContext2$locale = _useContext2.locale,
      locale = _useContext2$locale === void 0 ? 'en' : _useContext2$locale;

  var _ref = appConfig || {},
      menu = _ref.menu;

  var _ref2 = menu || {},
      MenuHeader = _ref2.MenuHeader,
      getMenuItems = _ref2.getMenuItems;

  var themeContext = useContext(ThemeContext);
  var menuItems = getMenuItems({
    intl,
    locale,
    updateLocale: setLocale,
    menuContext,
    themeContext,
    appConfig,
    a2HSContext
  }).filter(function (item) {
    return item.visible !== false;
  });
  var index = match ? match.path : '/';

  var handleChange = function handleChange(event, index) {
    if (index !== undefined) {
      setMobileOpen(false);
    }

    if (index !== undefined && index !== Object(index)) {
      history.push(index);
    }
  };

  return /*#__PURE__*/React.createElement(ResponsiveMenu, null, MenuHeader && /*#__PURE__*/React.createElement(MenuHeader, null), /*#__PURE__*/React.createElement("div", {
    style: {
      display: 'flex',
      flexDirection: 'column',
      height: '100%'
    }
  }, /*#__PURE__*/React.createElement(Scrollbar, {
    style: {
      flex: 1
    }
  }, /*#__PURE__*/React.createElement(SelectableMenuList, {
    items: menuItems,
    onIndexChange: handleChange,
    index: index,
    key: useMiniMode,
    useMinified: isMini && !isDesktopOpen
  }))));
};

export default Menu;